summaryrefslogtreecommitdiffstats
path: root/kresources/lib/groupwaredataadaptor.h
diff options
context:
space:
mode:
Diffstat (limited to 'kresources/lib/groupwaredataadaptor.h')
-rw-r--r--kresources/lib/groupwaredataadaptor.h66
1 files changed, 33 insertions, 33 deletions
diff --git a/kresources/lib/groupwaredataadaptor.h b/kresources/lib/groupwaredataadaptor.h
index 5cd72419..b7bd6e33 100644
--- a/kresources/lib/groupwaredataadaptor.h
+++ b/kresources/lib/groupwaredataadaptor.h
@@ -32,7 +32,7 @@
#include <tdepimmacros.h>
-namespace KIO {
+namespace TDEIO {
class TransferJob;
class Job;
}
@@ -70,11 +70,11 @@ class KDE_EXPORT GroupwareUploadItem
virtual KURL adaptNewItemUrl( GroupwareDataAdaptor *adaptor,
const KURL &url );
- virtual KIO::TransferJob *createRawUploadJob(
+ virtual TDEIO::TransferJob *createRawUploadJob(
GroupwareDataAdaptor *adaptor, const KURL &url );
- virtual KIO::TransferJob *createUploadNewJob(
+ virtual TDEIO::TransferJob *createUploadNewJob(
GroupwareDataAdaptor *adaptor, const KURL &url );
- virtual KIO::TransferJob *createUploadJob( GroupwareDataAdaptor *adaptor,
+ virtual TDEIO::TransferJob *createUploadJob( GroupwareDataAdaptor *adaptor,
const KURL &url );
virtual KPIM::FolderLister::ContentType itemType() { return mItemType; }
protected:
@@ -246,43 +246,43 @@ Q_OBJECT
// Creating jobs
/** Creates the KIO::Job for logging in to the server. This is only
* called if the GroupwareDataAdaptor::GWResNeedsLogin flag is set
* for the resource. */
- virtual KIO::Job *createLoginJob( const KURL &, const TQString &/*user*/,
+ virtual TDEIO::Job *createLoginJob( const KURL &, const TQString &/*user*/,
const TQString &/*password*/ ) { return 0; }
/** Creates the KIO::Job for logging off the server. This is only
* called if the GroupwareDataAdaptor::GWResNeedsLogoff flag is set
* for the resource. */
- virtual KIO::Job *createLogoffJob( const KURL &, const TQString &/*user*/,
+ virtual TDEIO::Job *createLogoffJob( const KURL &, const TQString &/*user*/,
const TQString &/*password*/ ) { return 0; }
- /** Creates the KIO::Job for listing all subfolders of the given url. */
- virtual KIO::Job *createListFoldersJob ( const KURL & ) = 0;
- /** Creates the KIO::TransferJob for listing all items in the given url. */
- virtual KIO::TransferJob *createListItemsJob( const KURL & ) = 0;
- /** Creates the KIO::TransferJob for downloading one given item. */
- virtual KIO::TransferJob *createDownloadJob( const KURL &,
+ /** Creates the TDEIO::Job for listing all subfolders of the given url. */
+ virtual TDEIO::Job *createListFoldersJob ( const KURL & ) = 0;
+ /** Creates the TDEIO::TransferJob for listing all items in the given url. */
+ virtual TDEIO::TransferJob *createListItemsJob( const KURL & ) = 0;
+ /** Creates the TDEIO::TransferJob for downloading one given item. */
+ virtual TDEIO::TransferJob *createDownloadJob( const KURL &,
FolderLister::ContentType ) = 0;
- /** Creates the KIO::TransferJob for downloading a list of items items. */
- virtual KIO::TransferJob *createDownloadJob( const TQMap<KURL,FolderLister::ContentType> & ) { return 0; }
+ /** Creates the TDEIO::TransferJob for downloading a list of items items. */
+ virtual TDEIO::TransferJob *createDownloadJob( const TQMap<KURL,FolderLister::ContentType> & ) { return 0; }
/** Create the job to remove the deletedItems from the server. The base
URL of the server is passed as uploadurl. */
- virtual KIO::Job *createRemoveJob( const KURL &,
+ virtual TDEIO::Job *createRemoveJob( const KURL &,
const KPIM::GroupwareUploadItem::List &/*deletedItems*/ ) { return 0; }
/** Create the job to remove the item from the server. The base
URL of the server is passed as uploadurl. */
- virtual KIO::Job *createRemoveJob( const KURL &,
+ virtual TDEIO::Job *createRemoveJob( const KURL &,
KPIM::GroupwareUploadItem */*deletedItem*/ ) { return 0; }
/** Create the job to change the item on the server (at the given URL) */
- virtual KIO::TransferJob *createUploadJob( const KURL &,
+ virtual TDEIO::TransferJob *createUploadJob( const KURL &,
GroupwareUploadItem *item );
/** Create the job to change the items on the server (at the given URL) */
- virtual KIO::TransferJob *createUploadJob( const KURL &, const GroupwareUploadItem::List &/*items*/ ) { return 0; }
+ virtual TDEIO::TransferJob *createUploadJob( const KURL &, const GroupwareUploadItem::List &/*items*/ ) { return 0; }
/** Create the job to add the item to the server (at the given baseURL) */
- virtual KIO::TransferJob *createUploadNewJob( const KURL &,
+ virtual TDEIO::TransferJob *createUploadNewJob( const KURL &,
GroupwareUploadItem *item );
/** Create the job to add the items to the server (at the given baseURL) */
- virtual KIO::TransferJob *createUploadNewJob( const KURL &, const GroupwareUploadItem::List &/*items*/ ) { return 0; }
+ virtual TDEIO::TransferJob *createUploadNewJob( const KURL &, const GroupwareUploadItem::List &/*items*/ ) { return 0; }
// Interpreting the result of the jobs
@@ -290,20 +290,20 @@ Q_OBJECT
* createLoginJob. Return true, if the login was successfull, or false
* if the user could not be authenticated or something else went wrong.
* In that case the resource will not be marked as open. */
- virtual bool interpretLoginJobResult( KIO::Job * ) { return true; }
+ virtual bool interpretLoginJobResult( TDEIO::Job * ) { return true; }
/** Extract the success information from the logoff job, created by
* createLogoffJob. */
- virtual bool interpretLogoffJobResult( KIO::Job * ) { return true; }
+ virtual bool interpretLogoffJobResult( TDEIO::Job * ) { return true; }
- virtual void interpretListFoldersJob( KIO::Job *, FolderLister *) = 0;
+ virtual void interpretListFoldersJob( TDEIO::Job *, FolderLister *) = 0;
/** Extract the list of items on the server and the list of items to be
downloaded from the results of the job (the job was created by
createListitemsJob). */
- virtual bool interpretListItemsJob( KIO::Job *, const TQString &jobData ) = 0;
- virtual bool interpretDownloadItemsJob( KIO::Job *job, const TQString &jobData ) = 0;
- virtual bool interpretRemoveJob( KIO::Job *job, const TQString &jobData );
- virtual bool interpretUploadJob( KIO::Job *job, const TQString &/*jobData*/ );
- virtual bool interpretUploadNewJob( KIO::Job *job, const TQString &/*jobData*/ );
+ virtual bool interpretListItemsJob( TDEIO::Job *, const TQString &jobData ) = 0;
+ virtual bool interpretDownloadItemsJob( TDEIO::Job *job, const TQString &jobData ) = 0;
+ virtual bool interpretRemoveJob( TDEIO::Job *job, const TQString &jobData );
+ virtual bool interpretUploadJob( TDEIO::Job *job, const TQString &/*jobData*/ );
+ virtual bool interpretUploadNewJob( TDEIO::Job *job, const TQString &/*jobData*/ );
virtual void processDownloadListItem( const KURL &entry,
const TQString &newFingerprint, KPIM::FolderLister::ContentType type );
@@ -312,8 +312,8 @@ Q_OBJECT
{
return TQString();
}
- virtual TQString uidFromJob( KIO::Job *job ) const;
- virtual void setUidForJob( KIO::Job *job, const TQString &uid );
+ virtual TQString uidFromJob( TDEIO::Job *job ) const;
+ virtual void setUidForJob( TDEIO::Job *job, const TQString &uid );
enum {
@@ -356,7 +356,7 @@ Q_OBJECT
TQString mUser;
TQString mPassword;
KPIM::IdMapper *mIdMapper;
- TQMap<KIO::Job*,TQString> mJobUIDMap;
+ TQMap<TDEIO::Job*,TQString> mJobUIDMap;
};
}
@@ -246,43 +246,43 @@ Q_OBJECT
// Creating jobs
- /** Creates the KIO::Job for logging in to the server. This is only
+ /** Creates the TDEIO::Job for logging in to the server. This is only
* called if the GroupwareDataAdaptor::GWResNeedsLogin flag is set
* for the resource. */
@@ -246,43 +246,43 @@ Q_OBJECT
const TQString &/*password*/ ) { return 0; }
- /** Creates the KIO::Job for logging off the server. This is only
+ /** Creates the TDEIO::Job for logging off the server. This is only
* called if the GroupwareDataAdaptor::GWResNeedsLogoff flag is set
* for the resource. */